@@ -30,8 +30,9 @@ class DockerSubprocessExecutor:
     
     def _get_container(self):
         """Get or create Docker container."""
-        if self.container is None:
-            self.container = self.docker_manager.get_or_create_container()
+        # Always get fresh container from docker manager
+        # This ensures we get a new container after cleanup
+        self.container = self.docker_manager.get_or_create_container()
         return self.container
     
     def execute_code(self, code: str, language: str, input_val: Any = None, 
@@ -104,8 +105,8 @@ try:
     if functions:
         func_name = functions[0]  # Use first function found
         func = all_globals[func_name]
-        
-        # Call function with input
+
+        # Call function with input and print the result
         result = func({repr(input_val)})
         print(result)
     else:
@@ -139,10 +140,10 @@ try:
     if functions:
         func_name = functions[0]  # Use first function found
         func = all_globals[func_name]
-        
+
         # Call function without parameters
-        result = func()
-        print(result)
+        # The function will handle its own output (print statements)
+        func()
     else:
         print("Error: No function found to test")
         sys.exit(1)
