@@ -399,6 +399,54 @@ except Exception as e:
             # Fallback to string comparison
             return str(actual).strip() == str(expected).strip()
 
+    def _compare_function_outputs(self, answer_output: str, code_output: str) -> bool:
+        """Compare outputs from two functions, handling print statements."""
+        try:
+            logger.debug(f"Comparing outputs: '{answer_output}' vs '{code_output}'")
+
+            # Normalize outputs by stripping whitespace (but preserve case!)
+            answer_normalized = str(answer_output).strip()
+            code_normalized = str(code_output).strip()
+
+            logger.debug(f"Normalized: '{answer_normalized}' vs '{code_normalized}'")
+
+            # Direct string comparison for print outputs (case-sensitive)
+            if answer_normalized == code_normalized:
+                logger.debug("Direct string comparison: MATCH")
+                return True
+
+            logger.debug("Direct string comparison: NO MATCH")
+
+            # Try to parse as numbers if they look numeric
+            try:
+                answer_num = float(answer_normalized)
+                code_num = float(code_normalized)
+                numeric_match = abs(answer_num - code_num) < 1e-9
+                logger.debug(f"Numeric comparison: {numeric_match}")
+                return numeric_match
+            except (ValueError, TypeError):
+                logger.debug("Not numeric values")
+                pass
+
+            # Try to compare as structured data (lists, dicts, etc.)
+            try:
+                import ast
+                answer_parsed = ast.literal_eval(answer_output.strip())
+                code_parsed = ast.literal_eval(code_output.strip())
+                structured_match = answer_parsed == code_parsed
+                logger.debug(f"Structured data comparison: {structured_match}")
+                return structured_match
+            except (ValueError, SyntaxError):
+                logger.debug("Not structured data")
+                pass
+
+            logger.debug("All comparisons failed - returning False")
+            return False
+
+        except Exception as e:
+            logger.warning(f"Function output comparison failed: {e}")
+            return False
+
     def _execute_input_output_mode_docker(self, inputs: List[Any], outputs: List[Any],
                                          code: str, language: str,
                                          timeout: Optional[int]) -> List[int]:
@@ -434,14 +482,58 @@ except Exception as e:
         try:
             print(f"[INFO] Executing function comparison using Docker {language}")
 
-            # For now, just execute the code and return success if no error
-            self.docker_subprocess_executor.execute_code(code, language, None, timeout)
-            return [1]
+            # Prepare function code with automatic function calls
+            answer_fn_with_call = self._add_function_call_if_needed(answer_fn, language)
+            code_with_call = self._add_function_call_if_needed(code, language)
+
+            # Execute both functions and compare their outputs
+            answer_output = self.docker_subprocess_executor.execute_code(answer_fn_with_call, language, None, timeout)
+            code_output = self.docker_subprocess_executor.execute_code(code_with_call, language, None, timeout)
+
+            # Debug output
+            logger.debug(f"Function comparison - Answer: '{answer_output}', Code: '{code_output}'")
+
+            # Compare the outputs (including print statements)
+            comparison_result = self._compare_function_outputs(answer_output, code_output)
+            logger.debug(f"Comparison result: {comparison_result}")
+
+            if comparison_result:
+                return [1]
+            else:
+                logger.debug(f"Function comparison failed - Answer: {answer_output}, Code: {code_output}")
+                return [0]
 
         except Exception as e:
             logger.error(f"Function comparison failed: {e}")
             return [0]
 
+    def _add_function_call_if_needed(self, code: str, language: str) -> str:
+        """Add function call if the code only contains function definition."""
+        if language.lower() == "python":
+            # Check if code already has function calls
+            lines = code.strip().split('\n')
+            has_function_call = False
+            function_name = None
+
+            # Find function definition and check for calls
+            for line in lines:
+                stripped = line.strip()
+                if stripped.startswith('def ') and '(' in stripped:
+                    # Extract function name
+                    func_def = stripped[4:].split('(')[0].strip()
+                    if function_name is None:
+                        function_name = func_def
+                elif function_name and (stripped == f"{function_name}()" or
+                                      stripped.startswith(f"{function_name}(")):
+                    has_function_call = True
+                    break
+
+            # If no function call found, add one
+            if function_name and not has_function_call:
+                return f"{code}\n{function_name}()"
+
+        return code
+
     def _execute_simple_mode_docker(self, code: str, language: str,
                                   timeout: Optional[int]) -> List[int]:
         """Execute simple mode using Docker subprocess."""
@@ -518,6 +610,10 @@ def rm_docker() -> None:
         cleanup_docker_subprocess_executor()
         cleanup_lazy_installer()
 
+        # Reset global executor instance to ensure fresh start
+        global _executor
+        _executor = None
+
         logger.info("All Docker containers and subprocess resources cleaned up")
     except Exception as e:
         logger.error(f"Failed to cleanup resources: {e}")
